@@ -9,7 +9,7 @@ Each 'Group' set of tests are run in parallel (default is all parallel).  Separa
 import os
 import shlex
 import subprocess
-import timeit
+import time
 
 from os import PathLike
 from pathlib import Path, PurePath
@@ -103,7 +103,7 @@ def _get_group_tests(
 
 
 def run_all_tests(test_cases: Tuple[TestCase, ...] = tuple()) -> None:
-    run_all_tests_start: str = "TIME_BRACKET"
+    start_time: float = time.perf_counter()
     running_test_cases: List[_RunningTestCase] = []
     test_count: int = 0
     tests_passed: int = 0
@@ -143,14 +143,12 @@ def run_all_tests(test_cases: Tuple[TestCase, ...] = tuple()) -> None:
 
         running_test_cases.clear()
 
-    # pylint: disable=pointless-string-statement
-    "TIME_BRACKET"
-    # pylint: enable=pointless-string-statement
-
-    elapsed_time: timeit.Timer = timeit.timeit(run_all_tests_start)
     if tests_passed == test_count:
-        print(f"\nAll {test_count} tests passed! ({elapsed_time})")
+        print(
+            f"\nAll {test_count} tests passed! ({time.perf_counter() - start_time}sec)"
+        )
     else:
         print(
-            f"\n{tests_passed} tests out of {test_count} passed ({elapsed_time})"
+            f"\n{tests_passed} tests out of {test_count} passed "
+            f"({time.perf_counter() - start_time}sec)"
         )
